@@ -33,9 +33,8 @@
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 #include <packagekit-glib2/packagekit.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -66,8 +65,9 @@ struct GpkAutoRefreshPrivate
 	gboolean		 force_get_updates_login;
 	guint			 force_get_updates_login_timeout_id;
 	guint			 timeout_id;
-	DkpClient		*client;
-	GConfClient		*gconf_client;
+	guint			 periodic_id;
+	UpClient		*client;
+	GSettings		*settings;
 	GpkSession		*session;
 	PkControl		*control;
 };
@@ -169,7 +169,7 @@ gpk_auto_refresh_get_time_refresh_cache_cb (GObject *object, GAsyncResult *res,
 	}
 
 	/* have we passed the timout? */
-	thresh = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (seconds < thresh) {
 		egg_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
 		return;
@@ -190,7 +190,7 @@ gpk_auto_refresh_maybe_refresh_cache (GpkAutoRefresh *arefresh)
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
 
 	/* if we don't want to auto check for updates, don't do this either */
-	thresh = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (thresh == 0) {
 		egg_debug ("not when policy is set to never");
 		return;
@@ -209,7 +209,7 @@ gpk_auto_refresh_maybe_refresh_cache (GpkAutoRefresh *arefresh)
 	}
 
 	/* get this each time, as it may have changed behind out back */
-	thresh = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_FREQUENCY_REFRESH_CACHE, NULL);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_REFRESH_CACHE);
 	if (thresh == 0) {
 		egg_debug ("not when policy is set to never");
 		return;
@@ -240,7 +240,7 @@ gpk_auto_refresh_get_time_get_updates_cb (GObject *object, GAsyncResult *res, Gp
 	}
 
 	/* have we passed the timout? */
-	thresh = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (seconds < thresh) {
 		egg_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
 		return;
@@ -262,15 +262,15 @@ gpk_auto_refresh_maybe_get_updates (GpkAutoRefresh *arefresh)
 
 	if (!arefresh->priv->force_get_updates_login) {
 		arefresh->priv->force_get_updates_login = TRUE;
-		if (gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_FORCE_GET_UPDATES_LOGIN, NULL)) {
-			egg_debug ("forcing get update due to GConf");
+		if (g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_FORCE_GET_UPDATES_LOGIN)) {
+			egg_debug ("forcing get update due to GSettings");
 			gpk_auto_refresh_signal_get_updates (arefresh);
 			return;
 		}
 	}
 
 	/* if we don't want to auto check for updates, don't do this either */
-	thresh = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (thresh == 0) {
 		egg_debug ("not when policy is set to never");
 		return;
@@ -301,7 +301,7 @@ gpk_auto_refresh_get_time_get_upgrades_cb (GObject *object, GAsyncResult *res, G
 	}
 
 	/* have we passed the timout? */
-	thresh = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (seconds < thresh) {
 		egg_debug ("not before timeout, thresh=%u, now=%u", thresh, seconds);
 		return;
@@ -322,7 +322,7 @@ gpk_auto_refresh_maybe_get_upgrades (GpkAutoRefresh *arefresh)
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
 
 	/* get this each time, as it may have changed behind out back */
-	thresh = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPGRADES, NULL);
+	thresh = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPGRADES);
 	if (thresh == 0) {
 		egg_debug ("not when policy is set to never");
 		return;
@@ -377,42 +377,51 @@ gpk_auto_refresh_change_state (GpkAutoRefresh *arefresh)
 	/* only force a check if the user REALLY, REALLY wants to break
 	 * set policy and have an update at startup */
 	if (!arefresh->priv->force_get_updates_login) {
-		force = gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_FORCE_GET_UPDATES_LOGIN, NULL);
+		force = g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_FORCE_GET_UPDATES_LOGIN);
 		if (force) {
 			/* don't immediately send the signal, if we are called during object initialization
 			 * we need to wait until upper layers  finish hooking up to the signal first. */
-			if (arefresh->priv->force_get_updates_login_timeout_id == 0)
+			if (arefresh->priv->force_get_updates_login_timeout_id == 0) {
 				arefresh->priv->force_get_updates_login_timeout_id =
-					g_timeout_add_seconds (GPK_UPDATES_LOGIN_TIMEOUT, (GSourceFunc) gpk_auto_refresh_maybe_get_updates_logon_cb, arefresh);
+					g_timeout_add_seconds (GPK_UPDATES_LOGIN_TIMEOUT,
+							       (GSourceFunc) gpk_auto_refresh_maybe_get_updates_logon_cb,
+							       arefresh);
+#if GLIB_CHECK_VERSION(2,25,8)
+				g_source_set_name_by_id (arefresh->priv->force_get_updates_login_timeout_id,
+							 "[GpkAutoRefresh] maybe-get-updates");
+#endif
+			}
 		}
 	}
 
 	/* wait a little time for things to settle down */
 	if (arefresh->priv->timeout_id != 0)
 		g_source_remove (arefresh->priv->timeout_id);
-	value = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_SESSION_STARTUP_TIMEOUT, NULL);
+	value = g_settings_get_int (arefresh->priv->settings, GPK_SETTINGS_SESSION_STARTUP_TIMEOUT);
 	egg_debug ("defering action for %i seconds", value);
-	arefresh->priv->timeout_id = g_timeout_add_seconds (value, (GSourceFunc) gpk_auto_refresh_change_state_cb, arefresh);
+	arefresh->priv->timeout_id =
+		g_timeout_add_seconds (value, (GSourceFunc) gpk_auto_refresh_change_state_cb, arefresh);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (arefresh->priv->timeout_id, "[GpkAutoRefresh] change-state");
+#endif
 
 	return TRUE;
 }
 
 /**
- * gpk_auto_refresh_gconf_key_changed_cb:
- *
- * We might have to do things when the gconf keys change; do them here.
+ * gpk_auto_refresh_key_changed_cb:
  **/
 static void
-gpk_auto_refresh_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpkAutoRefresh *arefresh)
+gpk_auto_refresh_key_changed_cb (GSettings *client, const gchar *key, GpkAutoRefresh *arefresh)
 {
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
-	if (g_strcmp0 (entry->key, GPK_CONF_SESSION_STARTUP_TIMEOUT) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FORCE_GET_UPDATES_LOGIN) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FREQUENCY_GET_UPDATES) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FREQUENCY_GET_UPGRADES) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_FREQUENCY_REFRESH_CACHE) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_AUTO_UPDATE) == 0 ||
-	    g_strcmp0 (entry->key, GPK_CONF_UPDATE_BATTERY) == 0)
+	if (g_strcmp0 (key, GPK_SETTINGS_SESSION_STARTUP_TIMEOUT) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FORCE_GET_UPDATES_LOGIN) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FREQUENCY_GET_UPDATES) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FREQUENCY_GET_UPGRADES) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_FREQUENCY_REFRESH_CACHE) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_AUTO_UPDATE) == 0 ||
+	    g_strcmp0 (key, GPK_SETTINGS_UPDATE_BATTERY) == 0)
 		gpk_auto_refresh_change_state (arefresh);
 }
 
@@ -457,11 +466,11 @@ gpk_auto_refresh_convert_network_state (GpkAutoRefresh *arefresh, PkNetworkEnum
 
 	/* check policy */
 	if (state == PK_NETWORK_ENUM_MOBILE)
-		return gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_CONNECTION_USE_MOBILE, NULL);
+		return g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_CONNECTION_USE_MOBILE);
 
 	/* check policy */
 	if (state == PK_NETWORK_ENUM_WIFI)
-		return gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_CONNECTION_USE_WIFI, NULL);
+		return g_settings_get_boolean (arefresh->priv->settings, GPK_SETTINGS_CONNECTION_USE_WIFI);
 
 	/* not recognised */
 	egg_warning ("state unknown: %i", state);
@@ -509,14 +518,14 @@ gpk_auto_refresh_timeout_cb (gpointer user_data)
  * gpk_auto_refresh_client_changed_cb:
  **/
 static void
-gpk_auto_refresh_client_changed_cb (DkpClient *client, GpkAutoRefresh *arefresh)
+gpk_auto_refresh_client_changed_cb (UpClient *client, GpkAutoRefresh *arefresh)
 {
 	gboolean on_battery;
 
 	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
 
 	/* get the on-battery state */
-	on_battery = dkp_client_on_battery (arefresh->priv->client);
+	on_battery = up_client_get_on_battery (arefresh->priv->client);
 	if (on_battery == arefresh->priv->on_battery) {
 		egg_debug ("same state as before, ignoring");
 		return;
@@ -570,17 +579,12 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	arefresh->priv->network_active = FALSE;
 	arefresh->priv->force_get_updates_login = FALSE;
 	arefresh->priv->timeout_id = 0;
+	arefresh->priv->periodic_id = 0;
 	arefresh->priv->force_get_updates_login_timeout_id = 0;
 
 	/* we need to know the updates frequency */
-	arefresh->priv->gconf_client = gconf_client_get_default ();
-
-	/* watch gnome-packagekit keys */
-	gconf_client_add_dir (arefresh->priv->gconf_client, GPK_CONF_DIR,
-			      GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_notify_add (arefresh->priv->gconf_client, GPK_CONF_DIR,
-				 (GConfClientNotifyFunc) gpk_auto_refresh_gconf_key_changed_cb,
-				 arefresh, NULL, NULL);
+	arefresh->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
+	g_signal_connect (arefresh->priv->settings, "changed", G_CALLBACK (gpk_auto_refresh_key_changed_cb), arefresh);
 
 	/* we need to query the last cache refresh time */
 	arefresh->priv->control = pk_control_new ();
@@ -590,13 +594,13 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	/* get network state */
 	pk_control_get_properties_async (arefresh->priv->control, NULL, (GAsyncReadyCallback) gpk_auto_refresh_get_properties_cb, arefresh);
 
-	/* use a DkpClient */
-	arefresh->priv->client = dkp_client_new ();
+	/* use a UpClient */
+	arefresh->priv->client = up_client_new ();
 	g_signal_connect (arefresh->priv->client, "changed",
 			  G_CALLBACK (gpk_auto_refresh_client_changed_cb), arefresh);
 
 	/* get the battery state */
-	arefresh->priv->on_battery = dkp_client_on_battery (arefresh->priv->client);
+	arefresh->priv->on_battery = up_client_get_on_battery (arefresh->priv->client);
 	egg_debug ("setting on battery %i", arefresh->priv->on_battery);
 
 	/* use gnome-session for the idle detection */
@@ -606,7 +610,12 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	arefresh->priv->session_idle = gpk_session_get_idle (arefresh->priv->session);
 
 	/* we check this in case we miss one of the async signals */
-	g_timeout_add_seconds (GPK_AUTO_REFRESH_PERIODIC_CHECK, gpk_auto_refresh_timeout_cb, arefresh);
+	arefresh->priv->periodic_id =
+		g_timeout_add_seconds (GPK_AUTO_REFRESH_PERIODIC_CHECK,
+				       gpk_auto_refresh_timeout_cb, arefresh);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (arefresh->priv->periodic_id, "[GpkAutoRefresh] periodic check");
+#endif
 
 	/* check system state */
 	gpk_auto_refresh_change_state (arefresh);
@@ -628,11 +637,13 @@ gpk_auto_refresh_finalize (GObject *object)
 
 	if (arefresh->priv->timeout_id != 0)
 		g_source_remove (arefresh->priv->timeout_id);
+	if (arefresh->priv->periodic_id != 0)
+		g_source_remove (arefresh->priv->periodic_id);
 	if (arefresh->priv->force_get_updates_login_timeout_id != 0)
 		g_source_remove (arefresh->priv->force_get_updates_login_timeout_id);
 
 	g_object_unref (arefresh->priv->control);
-	g_object_unref (arefresh->priv->gconf_client);
+	g_object_unref (arefresh->priv->settings);
 	g_object_unref (arefresh->priv->client);
 	g_object_unref (arefresh->priv->session);
 
